====================================
Correlative measures on spike trains
====================================

***********************
Spike train correlation
***********************

.. automodule:: elephant.spike_train_correlation


*************************
Spike train dissimilarity
*************************

.. automodule:: elephant.spike_train_dissimilarity


*********************
Spike train synchrony
*********************

.. automodule:: elephant.spike_train_synchrony


References
----------

.. bibliography::
    :keyprefix: correlation-

.. bibliography::
    :keyprefix: dissimilarity-

.. bibliography::
    :keyprefix: synchrony-
